@@ -14,9 +14,8 @@ import os
 
 from plib.ui import __version__
 from plib.ui.defs import *
-from plib.ui.imp import get_toolkit_object
 from plib.ui import common
-from plib.ui.app import PApplication
+from plib.ui.app import PApplication, PImageView
 from plib.ui.fileaware import PFileAware
 from plib.ui.widgets import *
 
@@ -117,7 +116,7 @@ class ImageViewer(PApplication):
     
     main_widget = tabwidget('images', [])
     
-    view_class = get_toolkit_object('imageview', 'PImageView')
+    view_class = PImageView
     
     filenames_to_open = None
     
