@@ -16,8 +16,7 @@ import xml.etree.ElementTree as etree
 
 from plib.ui import __version__
 from plib.ui.defs import *
-from plib.ui.imp import get_toolkit_object
-from plib.ui.app import PApplication
+from plib.ui.app import PApplication, PTreeView
 from plib.ui.fileaware import PFileAware
 from plib.ui.widgets import *
 
@@ -93,7 +92,7 @@ class XMLViewer(PApplication):
     
     main_widget = tabwidget('files', [])
     
-    view_class = get_toolkit_object('listview', 'PTreeView')
+    view_class = PTreeView
     view_header = ["Tag", "Attrs", "Text", "Tail"]
     view_font_size = 16 if sys.platform == 'darwin' else 12
     
