@@ -70,10 +70,8 @@ SIGNAL_TOGGLED = 102  # on/off widget has been toggled
 SIGNAL_SELECTED = 151  # item in widget has been selected; handler must take index param
 SIGNAL_BUTTONSELECTED = 156  # item in button group has been selected; handler must take index param
 SIGNAL_LISTVIEWSELECTED = 161  # list view item has changed; handler must take item param
-SIGNAL_LISTBOXSELECTED = 165  # list box item has changed; handler must take item param
+SIGNAL_LISTBOXSELECTED = 165  # list box item has changed; handler must take index param
 SIGNAL_CELLSELECTED = 171  # table current cell has changed; handler must take row, col params
-SIGNAL_FOCUS_IN = 191  # widget has received keyboard focus
-SIGNAL_FOCUS_OUT = 195  # widget has lost keyboard focus
 SIGNAL_CELLCHANGED = 301  # table cell text has changed; handler must take row, col params for changed cell
 SIGNAL_TEXTCHANGED = 401  # text in edit control has been changed
 SIGNAL_TEXTMODCHANGED = 406  # modification state of edit control has changed
@@ -103,6 +101,16 @@ SIGNAL_MINIMIZEEVENT = 955  # internal window minimize event that gets re-interp
 SIGNAL_CLOSEEVENT = 989  # internal main window close event that gets re-interpreted
 SIGNAL_BEFOREQUIT = 999  # app is about to quit
 
+# these signal constants are for custom widget signal mixins
+SIGNAL_FOCUS_IN = 191  # widget has received keyboard focus
+SIGNAL_FOCUS_OUT = 195  # widget has lost keyboard focus
+SIGNAL_LEFTCLICK = 201  # widget has received left mouse click
+SIGNAL_RIGHTCLICK = 205  # widget has received right mouse click
+SIGNAL_MIDDLECLICK = 207  # widget has received middle mouse click
+SIGNAL_LEFTDBLCLICK = 211  # widget has received left mouse double click
+SIGNAL_RIGHTDBLCLICK = 215  # widget has received right mouse double click
+SIGNAL_MIDDLEDBLCLICK = 217  # widget has received middle mouse double click
+
 # constants for action flags, used as keys
 ACTION_FILE_NEW = 5
 ACTION_FILE_OPEN = 10
@@ -204,8 +212,6 @@ WIDGET_EVENT_MAP = {
     SIGNAL_LISTVIEWSELECTED: 'selected',
     SIGNAL_LISTBOXSELECTED: 'selected',
     SIGNAL_CELLSELECTED: 'selected',
-    SIGNAL_FOCUS_IN: 'focus_in',
-    SIGNAL_FOCUS_OUT: 'focus_out',
     SIGNAL_CELLCHANGED: 'changed',
     SIGNAL_TEXTCHANGED: 'changed',
     SIGNAL_TEXTMODCHANGED: 'mod_changed',
@@ -217,6 +223,15 @@ WIDGET_EVENT_MAP = {
     SIGNAL_CLOSING: 'closing',
     SIGNAL_SHOWN: 'shown',
     SIGNAL_HIDDEN: 'hidden',
+    
+    SIGNAL_FOCUS_IN: 'focus_in',
+    SIGNAL_FOCUS_OUT: 'focus_out',
+    SIGNAL_LEFTCLICK: 'left_click',
+    SIGNAL_RIGHTCLICK: 'right_click',
+    SIGNAL_MIDDLECLICK: 'middle_click',
+    SIGNAL_LEFTDBLCLICK: 'left_dblclick',
+    SIGNAL_RIGHTDBLCLICK: 'right_dblclick',
+    SIGNAL_MIDDLEDBLCLICK: 'middle_dblclick',
 }
 
 add_handlers = WIDGET_EVENT_MAP.update
