@@ -28,9 +28,7 @@ class PTextOutput(object):
     def filesize(self):
         return len(self.control.get_text())
     
-    def truncate(self, size=None):
-        if size is None:
-            raise IOError("Must specify a size to truncate to (usually 0).")
+    def truncate(self, size=0):
         if size == 0:
             s = ""
         else:
