@@ -96,12 +96,19 @@ event_map = {
     SIGNAL_BUTTONSELECTED: ("sig_buttonSelected", (int,)),
     SIGNAL_CELLCHANGED: ("sig_cellChanged", (int, int)),
     SIGNAL_TEXTSTATECHANGED: ("sig_textStateChanged", ()),  # using selectionChanged above does not work
-    SIGNAL_FOCUS_IN: ("sig_focusInEvent", ()),
-    SIGNAL_FOCUS_OUT: ("sig_focusOutEvent", ()),
     SIGNAL_QUERYCLOSE: ("sig_canClose", ()),
     SIGNAL_CLOSING: ("sig_closeEvent", ()),
     SIGNAL_SHOWN: ("sig_showEvent", ()),
     SIGNAL_HIDDEN: ("sig_hideEvent", ()),
+    
+    SIGNAL_FOCUS_IN: ("sig_focusInEvent", ()),
+    SIGNAL_FOCUS_OUT: ("sig_focusOutEvent", ()),
+    SIGNAL_LEFTCLICK: ("sig_leftClickEvent", ()),
+    SIGNAL_RIGHTCLICK: ("sig_rightClickEvent", ()),
+    SIGNAL_MIDDLECLICK: ("sig_middleClickEvent", ()),
+    SIGNAL_LEFTDBLCLICK: ("sig_leftDblClickEvent", ()),
+    SIGNAL_RIGHTDBLCLICK: ("sig_rightDblClickEvent", ()),
+    SIGNAL_MIDDLEDBLCLICK: ("sig_middleDblClickEvent", ()),
 }
 
 
@@ -330,14 +337,6 @@ class PQtWidgetBase(PQtSignalBase):
     
     def set_focus(self):
         self.setFocus()
-    
-    def focusInEvent(self, event):
-        self.widget_class.focusInEvent(self, event)
-        self.do_notify(SIGNAL_FOCUS_IN)
-    
-    def focusOutEvent(self, event):
-        self.widget_class.focusOutEvent(self, event)
-        self.do_notify(SIGNAL_FOCUS_OUT)
 
 
 class PQtMessageBox(PMessageBoxBase):
