@@ -16,9 +16,10 @@ from plib.ui.defs import *
 from plib.ui.base.editctrl import PEditBoxBase, PNumEditBoxBase, PEditControlBase
 
 from .app import PQtWidgetMeta, PQtWidgetBase
+from .focus import PFocusMixin
 
 
-class PQtEditBase(PQtWidgetBase):
+class PQtEditBase(PFocusMixin, PQtWidgetBase):
     
     fn_get_read_only = 'isReadOnly'
     fn_set_read_only = 'setReadOnly'
