@@ -172,6 +172,9 @@ CellSelectedEvent, EVT_CELL_SELECTED = NewEvent()
 CellChangedEvent, EVT_CELL_CHANGED = NewEvent()
 TextModChangedEvent, EVT_TEXT_MOD_CHANGED = NewEvent()
 TextStateChangedEvent, EVT_TEXT_STATE_CHANGED = NewEvent()
+LeftClickEvent, EVT_LEFT_CLICK = NewEvent()
+RightClickEvent, EVT_RIGHT_CLICK = NewEvent()
+MiddleClickEvent, EVT_MIDDLE_CLICK = NewEvent()
 
 custom_map = {
     SIGNAL_BUTTONSELECTED: ButtonSelectedEvent,
@@ -182,7 +185,10 @@ custom_map = {
     SIGNAL_QUERYCLOSE: QueryCloseEvent,
     SIGNAL_CLOSING: ClosingEvent,
     SIGNAL_SHOWN: ShownEvent,
-    SIGNAL_HIDDEN: HiddenEvent
+    SIGNAL_HIDDEN: HiddenEvent,
+    SIGNAL_LEFTCLICK: LeftClickEvent,
+    SIGNAL_RIGHTCLICK: RightClickEvent,
+    SIGNAL_MIDDLECLICK: MiddleClickEvent,
 }
 
 event_map = {
@@ -193,6 +199,12 @@ event_map = {
     SIGNAL_BUTTONSELECTED: EVT_BUTTON_SELECTED,
     SIGNAL_FOCUS_IN: wx.EVT_SET_FOCUS,
     SIGNAL_FOCUS_OUT: wx.EVT_KILL_FOCUS,
+    SIGNAL_LEFTCLICK: EVT_LEFT_CLICK,
+    SIGNAL_RIGHTCLICK: EVT_RIGHT_CLICK,
+    SIGNAL_MIDDLECLICK: EVT_MIDDLE_CLICK,
+    SIGNAL_LEFTDBLCLICK: wx.EVT_LEFT_DCLICK,
+    SIGNAL_RIGHTDBLCLICK: wx.EVT_RIGHT_DCLICK,
+    SIGNAL_MIDDLEDBLCLICK: wx.EVT_MIDDLE_DCLICK,
     SIGNAL_LISTBOXSELECTED: wx.EVT_LISTBOX,
     SIGNAL_LISTVIEWSELECTED: wx.dataview.EVT_TREELIST_SELECTION_CHANGED,
     SIGNAL_CELLSELECTED: EVT_CELL_SELECTED,
@@ -302,6 +314,9 @@ wrapper_map = {
     SIGNAL_SELECTED: wx_selected_wrapper,
     SIGNAL_FOCUS_IN: wx_plain_wrapper,
     SIGNAL_FOCUS_OUT: wx_plain_wrapper,
+    SIGNAL_LEFTDBLCLICK: wx_plain_wrapper,
+    SIGNAL_RIGHTDBLCLICK: wx_plain_wrapper,
+    SIGNAL_MIDDLEDBLCLICK: wx_plain_wrapper,
     SIGNAL_LISTVIEWSELECTED: wx_listviewselected_wrapper,
     SIGNAL_LISTBOXSELECTED: wx_listboxselected_wrapper,
     SIGNAL_TEXTCHANGED: wx_plain_wrapper,
