@@ -45,14 +45,14 @@ class PDialog(PWxWidget, wx.Dialog, PDialogBase):
         else:
             super(PDialog, self).connect_target(signal, target)
     
-    def EndDialog(self, code):
+    def EndDialog(self, accepted):
         for handler in self.handlers:
-            handler(code)
+            handler(accepted)
         self.Show(False)
         self.Destroy()
     
     def accept_changes(self):
-        self.EndDialog(1)
+        self.EndDialog(True)
     
     def reject_changes(self):
-        self.EndDialog(0)
+        self.EndDialog(False)
