@@ -72,8 +72,11 @@ class PButtonGroupBase(PWxSequenceWidget, PButtonGroupMixin, PPanel):
     def is_checked(self, button):
         return button.GetValue()
     
-    def check_button(self, button):
-        button.SetValue(True)
+    def check_button(self, button, checked=True):
+        button.SetValue(checked)
+        # This event doesn't get fired by wx when the button is checked in code,
+        # so we have to emulate it manually
+        self.on_button_toggled(button, checked)
     
     def button_text(self, button):
         return button.GetLabel()
