@@ -8,49 +8,14 @@ See the LICENSE and README files for more information
 """
 
 from plib.stdlib.classtools import recurselist
-from plib.stdlib.imp import import_from_module
 
 from plib.ui.defs import *
+from plib.ui.imp import get_toolkit_object
 from plib.ui.common import action_name
-from plib.ui.toolkits import get_toolkit
-
-
-# Toolkit-aware widget class retrieval function
-
-def get_toolkit_class(modname, klassname):
-    if "." not in modname:
-        toolkit = get_toolkit()
-        modname = "plib.ui.toolkits.{}.{}".format(toolkit, modname)
-    return import_from_module(modname, klassname)
 
 
 # Helper function to find and connect signals to handlers
 
-WIDGET_EVENT_MAP = {
-    SIGNAL_ACTIVATED: None,
-    SIGNAL_CLICKED: 'clicked',
-    SIGNAL_TOGGLED: 'toggled',
-    SIGNAL_SELECTED: 'selected',
-    SIGNAL_BUTTONSELECTED: 'selected',
-    SIGNAL_LISTVIEWSELECTED: 'selected',
-    SIGNAL_LISTBOXSELECTED: 'selected',
-    SIGNAL_CELLSELECTED: 'selected',
-    SIGNAL_FOCUS_IN: 'focus_in',
-    SIGNAL_FOCUS_OUT: 'focus_out',
-    SIGNAL_CELLCHANGED: 'changed',
-    SIGNAL_TEXTCHANGED: 'changed',
-    SIGNAL_TEXTMODCHANGED: 'mod_changed',
-    SIGNAL_TEXTSTATECHANGED: 'state_changed',
-    SIGNAL_EDITCHANGED: 'changed',
-    SIGNAL_ENTER: 'enter',
-    SIGNAL_TABSELECTED: 'selected',
-    SIGNAL_QUERYCLOSE: 'queryclose',
-    SIGNAL_CLOSING: 'closing',
-    SIGNAL_SHOWN: 'shown',
-    SIGNAL_HIDDEN: 'hidden',
-}
-
-
 def setup_signal_handlers(manager, obj, name,
                           event_map=WIDGET_EVENT_MAP):
     
@@ -66,29 +31,6 @@ def setup_signal_handlers(manager, obj, name,
 # for each widget spec with the obvious arguments. The widget will
 # automagically find its event handlers on the manager when it is constructed
 
-WIDGET_ATTR_PREFIXES = {
-    # Only widgets whose prefix is different from their module name need this
-    'PCheckBox': 'checkbox',
-    'PEditBox': 'edit',
-    'PNumEditBox': 'edit',
-    'PPanel': 'panel',
-    'PButtonGroup': 'buttongroup',
-    'PRadioGroup': 'radiogroup',
-    'PTreeView': 'treeview',
-    'PEditControl': 'memo',
-    'PTextDisplay': 'text',
-    'PStatusLabel': 'label',
-}
-
-WIDGET_AUTO_PREFIXES = [
-    # These prefixes are used in auto_name and should not be further prefixed
-    'groupbox_',
-    'padding_',
-    'panel_',
-    'labelbox_',
-]
-
-
 def widget_from_spec(manager, parent, spec,
                      attr_prefixes=WIDGET_ATTR_PREFIXES, auto_prefixes=WIDGET_AUTO_PREFIXES):
     
@@ -106,7 +48,7 @@ def widget_from_spec(manager, parent, spec,
         spec = widget_manager.main_widget
     
     modname, klassname, name, args, kwargs = spec
-    klass = get_toolkit_class(modname, klassname)
+    klass = get_toolkit_object(modname, klassname)
     attrname = (
         name
         if any(name.startswith(prefix) for prefix in auto_prefixes) else
